/*
 * Byte ordering utilities.
 *
 * Copyright (C) 2023 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include "byteorder.h"



uint32_t get_stored_value(const uint8_t data[], uint8_t bytes, bool big_endian)
{ 
  uint32_t value = 0;
  
  if (big_endian)
  { 
    for (uint8_t byte = 0; byte < bytes; byte++)
      value = (value << 8) | data[byte];
  }
  else
  { 
    for (uint8_t byte = bytes; byte; byte--)
      value = (value << 8) | data[byte - 1];
  }
  
  return value;
}

void set_stored_value(uint32_t value, uint8_t data[], uint8_t bytes, bool big_endian)
{ 
  if (big_endian)
  { 
    for (uint8_t byte = bytes; byte; byte--)
    { 
      data[byte - 1] = value & 0xff;
      value >>= 8;
    }
  }
  else
  { 
    for (uint8_t byte = 0; byte < bytes; byte++)
    { 
      data[byte] = value & 0xff;
      value >>= 8;
    }
  }
}
